#===============================================================================
# GNU LESSER GENERAL PUBLIC LICENSE
#===============================================================================
# This source file is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by the
# Free Software Foundation; either version 2.1 of the License, or (at your
# option) any later version. This source is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Lesser General Public License for more details. You should have
# received a copy of the GNU Lesser General Public License along with this
# source; if not, download it from http://www.gnu.org/licenses/lgpl-2.1.html
#===============================================================================
# Qiang Du <du.qiang@gmail.com>
# 01/07/2015

import etherbone as eb
import sys

class EB:
    """ access a Etherbone device. """

    def __init__(self, ip):
        """ Initialize EB class.
        ip  -- IP address of Etherbone device
        """
        self.port_ip = 'udp/' + ip
        self.write_cnt = 0
        self.read_cnt = 0

    def open(self):
        self.socket = eb.Socket()
        self.socket.__enter__()

        self.device = eb.Device(self.socket, self.port_ip)
        self.device.__enter__()

    def close(self):
        self.device.close()
        self.socket.close()

    def write(self, addr, val):
        self.device.write(addr, val)

    def writemregs(self, addr, dlist):
        curr_addr = addr
        self.cycle = eb.Cycle(self.device, 0, 0)
        self.cycle.__enter__()
        for i in dlist:
            curr_addr += i
            self.cycle.write(curr_addr, i)
        self.cycle.close()

    def read(self, addr):
        return self.device.read(addr)

    def readmregs(self, addr, nrregs):
        curr_addr = addr
        dlist = []
        self.cycle = eb.Cycle(self.device, 0, 0)
        self.cycle.__enter__()
        for i in xrange(nrregs):
            curr_addr += i
            dlist[i] = self.cycle.read(curr_addr)
        self.cycle.close()
        return dlist
